@@ -37,19 +37,23 @@ def get_model_enum_values():
             try:
                 trans = member.translates()
                 res = []
-                for key in trans:
+                for key in member:
                     _d = {'_key': key}
                     for lang in ('en', 'zh'):
-                        _d[lang] = trans[key].get(lang)
-                        if _d[lang] is None:
+                        # if the given key is not need to be translated
+                        if key not in trans:
                             _d[lang] = key.replace('_', ' ').capitalize()
+                        else:
+                            _d[lang] = trans[key].get(lang)
+                            if _d[lang] is None:
+                                _d[lang] = key.replace('_', ' ').capitalize()
                     res.append(_d)
                 model_enums[name] = res
             except (AttributeError, KeyError) as ex:
                 log.warning('Enum %s has no proper translation defined', name)
                 res = []
                 for m in member.__members__:
-                    res.append({'_key': m, 'en': m.replace('_', ' ').capitalize()})
+                    res.append({'_key': m, 'en': m.replace('_', ' ').capitalize(), 'zh': m.replace('_', ' ').capitalize()})
                 model_enums[name] = res
     return model_enums
 
