@@ -37,31 +37,31 @@ class Gender(MultiLangEnum):
 class EyeColor(MultiLangEnum):
     blue = 'blue'
     black = 'black'
+    brown = 'brown'
     green = 'green'
     other = 'other'
-    brown = 'brown'
 
 class HairColor(MultiLangEnum):
     blue = 'blue'
     black = 'black'
+    blond = 'blond'
     red = 'red'
     other = 'other'
-    blond = 'blond'
 
 class Ethnicity(MultiLangEnum):
     asian = 'asian'
-    caucasian = 'caucasian'
     australian = 'australian'
+    caucasian = 'caucasian'
 
-class BuildType(MultiLangEnum):
-    slender = 'slender'
-    fit = 'fit'
-    skinny = 'skinny'
+class Build(MultiLangEnum):
     athletic = 'athletic'
     chunky = 'chunky'
+    fit = 'fit'
+    slender = 'slender'
+    skinny = 'skinny'
 
 
-class BustSize(MultiLangEnum):
+class Bust(MultiLangEnum):
     a = 'a'
     b = 'b'
     c = 'c'
@@ -80,15 +80,12 @@ class DressSize(MultiLangEnum):
 
 class SpeakingLanguage (MultiLangEnum):
     english = 'english'
-    mandarine = 'mandarine'
+    mandarin = 'mandarin'
     japanese = 'japanese'
     korean = 'korean'
     cantonese = 'cantonese'
 
 class PaymentMethod (MultiLangEnum):
-    card = 'card'
-    cash = 'cash'
-    payid = 'payid'
     usdt = 'usdt'
 
 class TimeSlotStatus(MultiLangEnum):
@@ -99,11 +96,11 @@ class TimeSlotStatus(MultiLangEnum):
 
 class BookingStatus(MultiLangEnum):
     attempt = 'attempt'
+    archived = 'archived'
     confirmed = 'confirmed'
     cancel_attempt = 'cancel_attempt'
     canceled = 'canceled'
     fulfilled = 'fulfilled'
-    archived = 'archived'
     deleted = 'deleted'  # need this? or simply delete it. as _id will conflict
 
 
@@ -117,13 +114,13 @@ class ProviderProfile(BaseProfile):
     contact_detail: str = None
     rate_aud: int = 150
     hair_color: Optional[HairColor]
-    build: Optional[BuildType]
+    build: Optional[Build]
     ethnicity: Optional[Ethnicity]
     eye_color: Optional[EyeColor]
     bio: Optional[str]
     photos: List[str] = []
     height: Optional[int]
-    bust: Optional[BustSize]
+    bust: Optional[Bust]
     rating: Optional[float]
     dress_size: Optional[DressSize]
     speaking_language: List[SpeakingLanguage] = []
